@@ -1,10 +1,13 @@
 package OpenGL::Sandbox::V1::FTGLFont;
-BEGIN { $OpenGL::Sandbox::V1::FTGLFont::VERSION = '0.041'; }
 use Moo;
 use Cwd;
+use OpenGL::Sandbox::V1 0.04;
 use OpenGL::Sandbox::MMap;
 
 # ABSTRACT: Wrapper object for FTGL Fonts
+BEGIN {
+our $VERSION = '0.042'; # VERSION
+}
 
 
 has filename => ( is => 'ro' );
@@ -65,7 +68,7 @@ OpenGL::Sandbox::V1::FTGLFont - Wrapper object for FTGL Fonts
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 DESCRIPTION
 
@@ -100,7 +103,7 @@ object.
 
 =head2 filename
 
-The name this data was loaded from, for reference purposes only.
+The name this data was loaded from, for informational purposes only.
 
 =head2 face_size
 
